﻿Imports Microsoft.TeamFoundation.Build.Client
Imports System.Management.Automation

<Cmdlet(VerbsLifecycle.Enable, TeamSystemNouns.BuildAgent, ConfirmImpact:=ConfirmImpact.Low, SupportsShouldProcess:=True)> _
Public Class EnableBuildAgentCmdlet
    Inherits TeamProjectCmdletBase

    Public Sub New()
    End Sub

    Private _name As String

    <Parameter(Position:=2, Mandatory:=True, ValueFromPipelineByPropertyName:=True), ValidateNotNullOrEmpty()> _
    Public Property Name() As String
        Get
            Return _name
        End Get
        Set(ByVal value As String)
            _name = value
        End Set
    End Property

    Private _passThru As SwitchParameter

    <Parameter()> _
    Public Property PassThru() As SwitchParameter
        Get
            Return _passThru
        End Get
        Set(ByVal value As SwitchParameter)
            _passThru = value
        End Set
    End Property

    Protected Overrides Sub ProcessRecord()
        Dim buildAgentSpec As IBuildAgentSpec
        buildAgentSpec = buildServer.CreateBuildAgentSpec(TeamProject, Name)

        Dim buildAgents As IBuildAgent()
        buildAgents = buildServer.QueryBuildAgents(buildAgentSpec).Agents

        If buildAgents.Length <> 1 Then
            'TODO
            WriteError(New ErrorRecord(Nothing, Nothing, ErrorCategory.ObjectNotFound, Nothing))
            Exit Sub
        End If

        Dim buildAgent As IBuildAgent
        buildAgent = buildAgents(0)

        buildAgent.Status = AgentStatus.Enabled

        If ShouldProcess(Name) Then
            buildAgent.Save()
        End If

        If PassThru.IsPresent Then
            'Refresh to retrieve new values for any other properties
            'that are modified as a result of changing the status to
            'disabled.
            buildAgent.Refresh()

            WriteObject(buildAgent)
        End If
    End Sub
End Class